==> cssadmin_1.0.2.zip: cssadmin/xoops_version.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/trpg>                      //
//  ------------------------------------------------------------------------ //

if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

$mydirname = basename( dirname( __FILE__ ) ) ;

//**************************************************************
//XOOPS⥸塼̤ε
//**************************************************************
//⥸塼̾
$modversion['name'] = _MI_CSSADMIN_MOD_NAME;
//⥸塼ΥС
$modversion['version'] = '1.0.2';
//⥸塼
$modversion['description'] = _MI_CSSADMIN_MOD_DESC;
//⥸塼Υ쥸åɸ
$modversion['credits'] = 'Word By Word';
//⥸塼κ̾
$modversion['author'] = 'gusagi( http://good-tea.ddo.jp/dev )';
//
$modversion['help'] = 'help.html';
//⥸塼Υ饤󥹷
$modversion['license'] = 'GNU General Public License Version 2(GPL2)';
//XOOPSθ⥸塼뤫ɤʥꥸʥ⥸塼0)
$modversion['official'] = 0;
//ԥ˥塼ɽ륢
$modversion['image'] = 'images/cssadmin_slogo.png';
//⥸塼֥ǥ쥯ȥ̾
$modversion['dirname'] = $mydirname;

//**************************************************************
//󥹥ȡϢ
//**************************************************************
//⥸塼Υ󥹥ȡ˻ȤSQLե̾
// - phpMyAdminˤäƺ줿SQLե侩ޤ
// - SQLեǤϡxoops_ ʤɤΤ褦ʡXOOPS󥹥ȡ
//   ԤץեåϴޤǤϤޤ

//$modversion['sqlfile']['mysql'] = "sql/" .$mydirname .".sql";
//$modversion['sqlfile']['mysql'] = "sql/mysql.sql";
//$modversion['sqlfile']['postgresql'] = "sql/pgsql.sql";

// ⥸塼Υ󥤥󥹥ȡDROPơ֥̾
// - ơ֥̾ˤϡxoops_ ʤɤΤ褦ʡXOOPS󥹥ȡ
//   ԤץեåϴޤǤϤޤ

//$modversion['tables'] = array(
//);


//򵭽Ҥեꤷޤ
//oninstall.inc.phpǤxoops_module_install_(⥸塼̾)Ȥ
//ؿ˽򵭽Ҥޤ
//⥸塼Υ󥹥ȡ뤬λΤˤν¹Ԥޤ
$modversion['onInstall'] = 'include/mycssadmin_oninstall.inc.php';

//**************************************************************
//åץǡȴϢ
//**************************************************************
//򵭽Ҥեꤷޤ
//onupdate.inc.phpǤxoops_module_update_(⥸塼̾)Ȥ
//ؿ˽򵭽Ҥޤ
//⥸塼ΥåץǡȤλΤˤν¹Ԥޤ
$modversion['onUpdate'] = 'include/mycssadmin_onupdate.inc.php';

//**************************************************************
//󥤥󥹥ȡϢ
//**************************************************************
//򵭽Ҥեꤷޤ
//onuninstall.inc.phpǤxoops_module_uninstall_(⥸塼̾)Ȥ
//ؿ˽򵭽Ҥޤ
//⥸塼Υ󥹥ȡ뤬λΤˤν¹Ԥޤ
$modversion['onUninstall'] = 'include/mycssadmin_onuninstall.inc.php';

//**************************************************************
//Smarty
//**************************************************************
//SmartyѾ1ʤ0
$modversion['use_smarty'] = 1;

//**************************************************************
//ѥƥץ졼
//**************************************************************
//$modversion['templates'][1] = array(
//  'file' => 'mobile_login_form.html',
//  'description' => ''
//);

//**************************************************************
//֥å
//**************************************************************
$module_dirname = basename( dirname(__FILE__) );
$modversion['blocks'][1] = array(
  'file'          => 'mycssadmin_hook.php' ,
  'name'          => 'mycssadmin block' ,
  'description'   => 'mycssadmin block' ,
  'show_func'     => $module_dirname .'_cssadmin_hook' ,
  'edit_func'     => '' ,
  'template'      => '' ,
  'options'       => ''
) ;
//$modversion['blocks'][1] = array(
//  'file'          => 'ModSample0_block1.php' ,
//  'name'          => _MI_MODSAMPLE0_BLOCK_BLOCK1 ,
//  'description'   => _MI_MODSAMPLE0_BLOCK_BLOCK1_DESC ,
//  'show_func'     => 'ModSample0_block1_show' ,
//  'edit_func'     => 'ModSample0_block1_edit' ,
//  'template'      => 'ModSample0_block1.html' ,
//  'options'       => '10|20'
//) ;
//
//Key:file
//֥åPHPե̾
// - ֥åPHPեϡblocksǥ쥯ȥ
//   ֤ȤʤäƤޤ
//
//Key:name
//֥å̾
//
//Key:description
//֥å
//
//Key:show_func
//֥åɽؿ̾
// - fileѥ᡼ǻꤷPHPɽѴؿꤷޤ
//
//Key:edit_func
//֥åꥪץɽؿ̾
// - ԥ˥塼Υ֥åɽץꤹɬפ
//   ˡΥץʬɽ뤿δؿ̾
//   ꤷޤ
// - ֥åꤷץͤϡshow_funcڤedit_func
//   ꤷؿΥѥ᡼ȤarrayϤޤ
//
//Key:template
//֥åɽѥƥץ졼ȥե̾
// - ֥åɽ˥ƥץ졼ȤѤˤΥƥץ졼
//   ե̾ꤷޤ
// - ֥åɽѥƥץ졼ȥեϡtemplates/blocks
//   ֤ȤʤäƤޤ
//
//Key:options
//֥åꥪץΥǥե
// - ֥åˤɽץΥǥեͤꤷޤ
// - ץʣ濫ˤϡ줾'|'Ƕڤäƻꤷޤ

//**************************************************************
//ᥤ˥塼
//**************************************************************
//ᥤ˥塼˥⥸塼ɽ1ɽʤ0
// - ᥤ˥塼ɽ硢ƥ˥塼򤹤ȡ⥸塼
//   index.phpƤӽФޤ
$modversion['hasMain'] = 0;

//ᥤ˥塼γإ֥˥塼
// - إ֥˥塼ɽɬפʾ˻ꤷޤ
//$modversion['sub'][1]=array(
//  'name' => _MI_MODSAMPLE0_SUBMENU1,
//  'url'  => "submenu1.php",
//);
//
//Key:name
//֥˥塼ɽ̾
//
//Key:url
//֥˥塼򤷤˼¹ԤURL
//
//ǽˤäƤϡΥåʤɤΥåޤơ
//֥˥塼ɽɽؤԤäꡢ֥˥塼
//ɽܤDBɤ߼äꤹ⤢ޤ

//**************************************************************
//ǽ
//**************************************************************
//XOOPSΥɸǽθоݤȤ1ʤ0
$modversion['hasSearch'] = 0;

//ǽ
//$modversion['search'] = array(
//  'file' => "include/search.inc.php",
//  'func' => "ModSample0_search",
//);
//
//Key:file
//ǽPHPե̾
//
//Key:func
//ؿ̾
// - fileѥ᡼ǻꤷPHPɽѴؿꤷޤ
// - XOOPSΥɸԤȡǻꤵ줿ؿˡ
//   ʸʤɤѥ᡼ȤƼ錄ޤ

//**************************************************************
//ȵǽ
//**************************************************************
//ᥤ󥳥ƥĤФ륳ƤĤ1ʤ0
$modversion['hasComments'] = 0;

//°
//$modversion['comments'] = array(
//  'itemName' => 'event_id',
//  'pageName' => 'index.php',
//  'callbackFile' => 'include/comment_functions.php',
//  'callback' => array(
//      'approve' => 'ModSample0_comments_approve',
//      'update' => 'ModSample0_comments_update',
//  ),
//);

//**************************************************************
//ԥ˥塼Ϣ
//**************************************************************
//ԥ˥塼Ǥ굡ǽľ1ʤ0
$modversion['hasAdmin'] = 1;

//ԥ˥塼Υ򤷤ȤνPHPե̾
$modversion['adminindex'] = "admin/index.php";

//ԥ˥塼Υ򤷤ȤΥ˥塼ɽPHPե̾
$modversion['adminmenu'] = "admin/menu.php";

//**************************************************************
//ԥ˥塼Ϣ
//**************************************************************
//ԥ˥塼Ǥ̤ư1
// - ̤μưǤϡ̾ȸƤФƤ̤ˡ
//   ʲꤷܤɲɽޤ
$modversion['hasconfig'] = 0;

//ꥪץե
// - ɲɽܤ
//$modversion['config'][1] = array(
//  'name'          => 'ModSample0_field1' ,
//  'title'         => '_MI_MODSAMPLE0_FIELD1' ,
//  'description'   => '_MI_MODSAMPLE0_FIELD1_DESC' ,
//  'formtype'      => 'textbox' ,
//  'valuetype'     => 'text' ,
//  'default'       => 'DEFAULT' ,
//  'options'       => array(),
//);
//Key:name
// ꥪץΥ̾
// - Хѿ $xoopsModuleConfig[̾]ˤơͤǽˤʤޤ
//
//Key:title
// ꥪץɽ̾
// - ̤ɽ륪ץ̾Τꤷޤ
//
//Key:description
//ꥪץ
// - ̤ɽ륪ץꤷޤ
//
//Key:formtype
//ꥪץΥǡɽ
// - ̤ɽ륪ץͤɤΤ褦ɽ뤫μ̤ꤷޤ
// - ʲͤѲǽǤ
//      textbox
//      textarea
//      select
//      select_multi
//      yesno
//      group
//      group_multi
//
//Key:valuetype
//ꥪץΥǡ
// - ʲͤѲǽǤ
//      int
//      text
//      float
//      array
//      other
// - formtypegroup_multiselect_multiꤷˤϡarrayꤹɬפޤ
//
//Key:default
// ꥪץΥǥե
// - ǥե̵ͤˤϡפǤ
// - formtype 'yesno'ξˤϡ0(no)1(yes)ꤷޤ
//
//Key:options
//ꥪץܰ
// - formtype 'select''select_multi'ξˡоݹܤǼarrayꤷޤ
//    'options' => array(
//                    '_MI_OPT_AUTH_NONE'=>0 ,
//                    '_MI_OPT_AUTH_WAIT'=>1 ,
//                    '_MI_OPT_AUTH_POST'=>3 ,
//                    '_MI_OPT_AUTH_BYGROUP'=>256 ,
//       )

//**************************************************************
//٥εǽ
//**************************************************************
//٥εǽľ1ʤ0
$modversion['hasNotification'] = 0;

//$modversion['notification']['lookup_file'] = 'include/notification.inc.php';
//$modversion['notification']['lookup_func'] = 'ModSample0_notify_iteminfo';

//٥ȤΥƥ꡼
//$modversion['notification']['category'][1] = array(
//  'name' => 'global',
//  'title' => _MI_MODSAMPLE0_GLOBAL_NOTIFY,
//  'description' => _MI_MODSAMPLE0_GLOBAL_NOTIFYDSC,
//  'subscribe_from' => array(
//      'index.php',
//  ),
//  'item_name' => 'cid',
//  'allow_bookmark' => 0,
//);

//Υ٥Ȥ
//$modversion['notification']['event'][1] = array(
//  'name' => 'new_event',
//  'category' => 'global',
//  'title' => _MI_MODSAMPLE0_GLOBAL_NEWEVENT_NOTIFY,
//  'caption' => _MI_MODSAMPLE0_GLOBAL_NEWEVENT_NOTIFYCAP,
//  'description' => _MI_MODSAMPLE0_GLOBAL_NEWEVENT_NOTIFYDSC,
//  'mail_template' => 'global_newevent_notify',
//  'mail_subject' => _MI_MODSAMPLE0_GLOBAL_NEWEVENT_NOTIFYSBJ,
//);

?>

==> cssadmin_1.0.4.zip: cssadmin/xoops_version.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/trpg>                      //
//  ------------------------------------------------------------------------ //

if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

$mydirname = basename( dirname( __FILE__ ) ) ;

//**************************************************************
//XOOPS⥸塼̤ε
//**************************************************************
//⥸塼̾
$modversion['name'] = _MI_CSSADMIN_MOD_NAME;
//⥸塼ΥС
$modversion['version'] = '1.0.4';
//⥸塼
$modversion['description'] = _MI_CSSADMIN_MOD_DESC;
//⥸塼Υ쥸åɸ
$modversion['credits'] = 'Word By Word';
//⥸塼κ̾
$modversion['author'] = 'gusagi( http://good-tea.ddo.jp/dev )';
//
$modversion['help'] = 'help.html';
//⥸塼Υ饤󥹷
$modversion['license'] = 'GNU General Public License Version 2(GPL2)';
//XOOPSθ⥸塼뤫ɤʥꥸʥ⥸塼0)
$modversion['official'] = 0;
//ԥ˥塼ɽ륢
$modversion['image'] = 'images/cssadmin_slogo.png';
//⥸塼֥ǥ쥯ȥ̾
$modversion['dirname'] = $mydirname;

//**************************************************************
//󥹥ȡϢ
//**************************************************************
//⥸塼Υ󥹥ȡ˻ȤSQLե̾
// - phpMyAdminˤäƺ줿SQLե侩ޤ
// - SQLեǤϡxoops_ ʤɤΤ褦ʡXOOPS󥹥ȡ
//   ԤץեåϴޤǤϤޤ

//$modversion['sqlfile']['mysql'] = "sql/" .$mydirname .".sql";
//$modversion['sqlfile']['mysql'] = "sql/mysql.sql";
//$modversion['sqlfile']['postgresql'] = "sql/pgsql.sql";

// ⥸塼Υ󥤥󥹥ȡDROPơ֥̾
// - ơ֥̾ˤϡxoops_ ʤɤΤ褦ʡXOOPS󥹥ȡ
//   ԤץեåϴޤǤϤޤ

//$modversion['tables'] = array(
//);


//򵭽Ҥեꤷޤ
//oninstall.inc.phpǤxoops_module_install_(⥸塼̾)Ȥ
//ؿ˽򵭽Ҥޤ
//⥸塼Υ󥹥ȡ뤬λΤˤν¹Ԥޤ
$modversion['onInstall'] = 'include/mycssadmin_onadmin.inc.php';

//**************************************************************
//åץǡȴϢ
//**************************************************************
//򵭽Ҥեꤷޤ
//onupdate.inc.phpǤxoops_module_update_(⥸塼̾)Ȥ
//ؿ˽򵭽Ҥޤ
//⥸塼ΥåץǡȤλΤˤν¹Ԥޤ
$modversion['onUpdate'] = 'include/mycssadmin_onadmin.inc.php';

//**************************************************************
//󥤥󥹥ȡϢ
//**************************************************************
//򵭽Ҥեꤷޤ
//onuninstall.inc.phpǤxoops_module_uninstall_(⥸塼̾)Ȥ
//ؿ˽򵭽Ҥޤ
//⥸塼Υ󥹥ȡ뤬λΤˤν¹Ԥޤ
$modversion['onUninstall'] = 'include/mycssadmin_onadmin.inc.php';

//**************************************************************
//Smarty
//**************************************************************
//SmartyѾ1ʤ0
$modversion['use_smarty'] = 1;

//**************************************************************
//ѥƥץ졼
//**************************************************************
//$modversion['templates'][1] = array(
//  'file' => 'mobile_login_form.html',
//  'description' => ''
//);

//**************************************************************
//֥å
//**************************************************************
$module_dirname = basename( dirname(__FILE__) );
$modversion['blocks'][1] = array(
  'file'          => 'mycssadmin_hook.php' ,
  'name'          => 'mycssadmin block' ,
  'description'   => 'mycssadmin block' ,
  'show_func'     => $module_dirname .'_cssadmin_hook' ,
  'edit_func'     => '' ,
  'template'      => '' ,
  'options'       => ''
) ;
//$modversion['blocks'][1] = array(
//  'file'          => 'ModSample0_block1.php' ,
//  'name'          => _MI_MODSAMPLE0_BLOCK_BLOCK1 ,
//  'description'   => _MI_MODSAMPLE0_BLOCK_BLOCK1_DESC ,
//  'show_func'     => 'ModSample0_block1_show' ,
//  'edit_func'     => 'ModSample0_block1_edit' ,
//  'template'      => 'ModSample0_block1.html' ,
//  'options'       => '10|20'
//) ;
//
//Key:file
//֥åPHPե̾
// - ֥åPHPեϡblocksǥ쥯ȥ
//   ֤ȤʤäƤޤ
//
//Key:name
//֥å̾
//
//Key:description
//֥å
//
//Key:show_func
//֥åɽؿ̾
// - fileѥ᡼ǻꤷPHPɽѴؿꤷޤ
//
//Key:edit_func
//֥åꥪץɽؿ̾
// - ԥ˥塼Υ֥åɽץꤹɬפ
//   ˡΥץʬɽ뤿δؿ̾
//   ꤷޤ
// - ֥åꤷץͤϡshow_funcڤedit_func
//   ꤷؿΥѥ᡼ȤarrayϤޤ
//
//Key:template
//֥åɽѥƥץ졼ȥե̾
// - ֥åɽ˥ƥץ졼ȤѤˤΥƥץ졼
//   ե̾ꤷޤ
// - ֥åɽѥƥץ졼ȥեϡtemplates/blocks
//   ֤ȤʤäƤޤ
//
//Key:options
//֥åꥪץΥǥե
// - ֥åˤɽץΥǥեͤꤷޤ
// - ץʣ濫ˤϡ줾'|'Ƕڤäƻꤷޤ

//**************************************************************
//ᥤ˥塼
//**************************************************************
//ᥤ˥塼˥⥸塼ɽ1ɽʤ0
// - ᥤ˥塼ɽ硢ƥ˥塼򤹤ȡ⥸塼
//   index.phpƤӽФޤ
$modversion['hasMain'] = 0;

//ᥤ˥塼γإ֥˥塼
// - إ֥˥塼ɽɬפʾ˻ꤷޤ
//$modversion['sub'][1]=array(
//  'name' => _MI_MODSAMPLE0_SUBMENU1,
//  'url'  => "submenu1.php",
//);
//
//Key:name
//֥˥塼ɽ̾
//
//Key:url
//֥˥塼򤷤˼¹ԤURL
//
//ǽˤäƤϡΥåʤɤΥåޤơ
//֥˥塼ɽɽؤԤäꡢ֥˥塼
//ɽܤDBɤ߼äꤹ⤢ޤ

//**************************************************************
//ǽ
//**************************************************************
//XOOPSΥɸǽθоݤȤ1ʤ0
$modversion['hasSearch'] = 0;

//ǽ
//$modversion['search'] = array(
//  'file' => "include/search.inc.php",
//  'func' => "ModSample0_search",
//);
//
//Key:file
//ǽPHPե̾
//
//Key:func
//ؿ̾
// - fileѥ᡼ǻꤷPHPɽѴؿꤷޤ
// - XOOPSΥɸԤȡǻꤵ줿ؿˡ
//   ʸʤɤѥ᡼ȤƼ錄ޤ

//**************************************************************
//ȵǽ
//**************************************************************
//ᥤ󥳥ƥĤФ륳ƤĤ1ʤ0
$modversion['hasComments'] = 0;

//°
//$modversion['comments'] = array(
//  'itemName' => 'event_id',
//  'pageName' => 'index.php',
//  'callbackFile' => 'include/comment_functions.php',
//  'callback' => array(
//      'approve' => 'ModSample0_comments_approve',
//      'update' => 'ModSample0_comments_update',
//  ),
//);

//**************************************************************
//ԥ˥塼Ϣ
//**************************************************************
//ԥ˥塼Ǥ굡ǽľ1ʤ0
$modversion['hasAdmin'] = 1;

//ԥ˥塼Υ򤷤ȤνPHPե̾
$modversion['adminindex'] = "admin/index.php";

//ԥ˥塼Υ򤷤ȤΥ˥塼ɽPHPե̾
$modversion['adminmenu'] = "admin/menu.php";

//**************************************************************
//ԥ˥塼Ϣ
//**************************************************************
//ԥ˥塼Ǥ̤ư1
// - ̤μưǤϡ̾ȸƤФƤ̤ˡ
//   ʲꤷܤɲɽޤ
$modversion['hasconfig'] = 0;

//ꥪץե
// - ɲɽܤ
//$modversion['config'][1] = array(
//  'name'          => 'ModSample0_field1' ,
//  'title'         => '_MI_MODSAMPLE0_FIELD1' ,
//  'description'   => '_MI_MODSAMPLE0_FIELD1_DESC' ,
//  'formtype'      => 'textbox' ,
//  'valuetype'     => 'text' ,
//  'default'       => 'DEFAULT' ,
//  'options'       => array(),
//);
//Key:name
// ꥪץΥ̾
// - Хѿ $xoopsModuleConfig[̾]ˤơͤǽˤʤޤ
//
//Key:title
// ꥪץɽ̾
// - ̤ɽ륪ץ̾Τꤷޤ
//
//Key:description
//ꥪץ
// - ̤ɽ륪ץꤷޤ
//
//Key:formtype
//ꥪץΥǡɽ
// - ̤ɽ륪ץͤɤΤ褦ɽ뤫μ̤ꤷޤ
// - ʲͤѲǽǤ
//      textbox
//      textarea
//      select
//      select_multi
//      yesno
//      group
//      group_multi
//
//Key:valuetype
//ꥪץΥǡ
// - ʲͤѲǽǤ
//      int
//      text
//      float
//      array
//      other
// - formtypegroup_multiselect_multiꤷˤϡarrayꤹɬפޤ
//
//Key:default
// ꥪץΥǥե
// - ǥե̵ͤˤϡפǤ
// - formtype 'yesno'ξˤϡ0(no)1(yes)ꤷޤ
//
//Key:options
//ꥪץܰ
// - formtype 'select''select_multi'ξˡоݹܤǼarrayꤷޤ
//    'options' => array(
//                    '_MI_OPT_AUTH_NONE'=>0 ,
//                    '_MI_OPT_AUTH_WAIT'=>1 ,
//                    '_MI_OPT_AUTH_POST'=>3 ,
//                    '_MI_OPT_AUTH_BYGROUP'=>256 ,
//       )

//**************************************************************
//٥εǽ
//**************************************************************
//٥εǽľ1ʤ0
$modversion['hasNotification'] = 0;

//$modversion['notification']['lookup_file'] = 'include/notification.inc.php';
//$modversion['notification']['lookup_func'] = 'ModSample0_notify_iteminfo';

//٥ȤΥƥ꡼
//$modversion['notification']['category'][1] = array(
//  'name' => 'global',
//  'title' => _MI_MODSAMPLE0_GLOBAL_NOTIFY,
//  'description' => _MI_MODSAMPLE0_GLOBAL_NOTIFYDSC,
//  'subscribe_from' => array(
//      'index.php',
//  ),
//  'item_name' => 'cid',
//  'allow_bookmark' => 0,
//);

//Υ٥Ȥ
//$modversion['notification']['event'][1] = array(
//  'name' => 'new_event',
//  'category' => 'global',
//  'title' => _MI_MODSAMPLE0_GLOBAL_NEWEVENT_NOTIFY,
//  'caption' => _MI_MODSAMPLE0_GLOBAL_NEWEVENT_NOTIFYCAP,
//  'description' => _MI_MODSAMPLE0_GLOBAL_NEWEVENT_NOTIFYDSC,
//  'mail_template' => 'global_newevent_notify',
//  'mail_subject' => _MI_MODSAMPLE0_GLOBAL_NEWEVENT_NOTIFYSBJ,
//);

?>
